struct Key {
text: String,
size: u32,
wrap: u32,
}Expand description
What a laid-out run is filed under. The two lengths are keyed by their bits: they are exactly as equal as the layouts they produce, and a font states its size as a float.
Fields
text: Stringsize: u32wrap: u32Implementations