struct Shaped {
id: GlyphId,
cluster: usize,
advance: f32,
}Expand description
One glyph as the shaper reports it, in font units.
Fields
id: GlyphIdcluster: usizeWhere in the paragraph the characters this glyph stands for begin.
advance: f32Auto Trait Implementations
impl Freeze for Shaped
impl RefUnwindSafe for Shaped
impl Send for Shaped
impl Sync for Shaped
impl Unpin for Shaped
impl UnsafeUnpin for Shaped
impl UnwindSafe for Shaped